@@ -90,6 +90,9 @@ new SnsToLambda(this, "test-lambda-sqs-stack", new SnsToLambdaProps.Builder()
 |lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |existingTopicObj?|[`sns.Topic`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Existing instance of SNS Topic object, providing both this and `topicProps` will cause an error.|
 |topicProps?|[`sns.TopicProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sns.TopicProps.html)|Optional user provided properties to override the default properties for the SNS topic.|
+|enableEncryptionWithCustomerManagedKey?|`boolean`|If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps.|
+|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SNS Topic with.|
+|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html#construct-props)|Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with.|
 
 ## Pattern Properties
 
@@ -140,6 +143,7 @@ from typeguard import check_type
 
 from ._jsii import *
 
+import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
 import aws_cdk.aws_sns
 import constructs
@@ -159,6 +163,9 @@ class SnsToLambda(
         scope: constructs.Construct,
         id: builtins.str,
         *,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
         lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
@@ -167,6 +174,9 @@ class SnsToLambda(
         '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps. Default: - False if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SNS Topic with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
@@ -181,6 +191,9 @@ class SnsToLambda(
                 scope: constructs.Construct,
                 id: builtins.str,
                 *,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
                 existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
                 existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
                 lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
@@ -191,6 +204,9 @@ class SnsToLambda(
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SnsToLambdaProps(
+            enable_encryption_with_customer_managed_key=enable_encryption_with_customer_managed_key,
+            encryption_key=encryption_key,
+            encryption_key_props=encryption_key_props,
             existing_lambda_obj=existing_lambda_obj,
             existing_topic_obj=existing_topic_obj,
             lambda_function_props=lambda_function_props,
@@ -214,6 +230,9 @@ class SnsToLambda(
     jsii_type="@aws-solutions-constructs/aws-sns-lambda.SnsToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
+        "enable_encryption_with_customer_managed_key": "enableEncryptionWithCustomerManagedKey",
+        "encryption_key": "encryptionKey",
+        "encryption_key_props": "encryptionKeyProps",
         "existing_lambda_obj": "existingLambdaObj",
         "existing_topic_obj": "existingTopicObj",
         "lambda_function_props": "lambdaFunctionProps",
@@ -224,12 +243,18 @@ class SnsToLambdaProps:
     def __init__(
         self,
         *,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
         lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps. Default: - False if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SNS Topic with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
@@ -237,6 +262,8 @@ class SnsToLambdaProps:
 
         :summary: The properties for the SnsToLambda class.
         '''
+        if isinstance(encryption_key_props, dict):
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(topic_props, dict):
@@ -244,6 +271,9 @@ class SnsToLambdaProps:
         if __debug__:
             def stub(
                 *,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
                 existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
                 existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
                 lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
@@ -251,11 +281,20 @@ class SnsToLambdaProps:
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
             check_type(argname="argument existing_topic_obj", value=existing_topic_obj, expected_type=type_hints["existing_topic_obj"])
             check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
             check_type(argname="argument topic_props", value=topic_props, expected_type=type_hints["topic_props"])
         self._values: typing.Dict[str, typing.Any] = {}
+        if enable_encryption_with_customer_managed_key is not None:
+            self._values["enable_encryption_with_customer_managed_key"] = enable_encryption_with_customer_managed_key
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
+        if encryption_key_props is not None:
+            self._values["encryption_key_props"] = encryption_key_props
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if existing_topic_obj is not None:
@@ -265,6 +304,37 @@ class SnsToLambdaProps:
         if topic_props is not None:
             self._values["topic_props"] = topic_props
 
+    @builtins.property
+    def enable_encryption_with_customer_managed_key(
+        self,
+    ) -> typing.Optional[builtins.bool]:
+        '''If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key.
+
+        This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps.
+
+        :default: - False if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        '''
+        result = self._values.get("enable_encryption_with_customer_managed_key")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+        '''An optional, imported encryption key to encrypt the SNS Topic with.
+
+        :default: - None
+        '''
+        result = self._values.get("encryption_key")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+
+    @builtins.property
+    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+        '''Optional user provided properties to override the default properties for the KMS encryption key used to  encrypt the SNS Topic with.
+
+        :default: - None
+        '''
+        result = self._values.get("encryption_key_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
